#[non_exhaustive]pub enum UnicodeVersion {
V9_0_0,
V10_0_0,
V11_0_0,
V12_0_0,
V12_1_0,
V13_0_0,
V14_0_0,
V15_0_0,
V15_1_0,
V16_0_0,
V17_0_0,
}Expand description
Supported Unicode versions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
V9_0_0
Unicode 9.0.0
V10_0_0
Unicode 10.0.0
V11_0_0
Unicode 11.0.0
V12_0_0
Unicode 12.0.0
V12_1_0
Unicode 12.1.0
V13_0_0
Unicode 13.0.0
V14_0_0
Unicode 14.0.0
V15_0_0
Unicode 15.0.0
V15_1_0
Unicode 15.1.0
V16_0_0
Unicode 16.0.0
V17_0_0
Unicode 17.0.0
Implementations
Sourceimpl UnicodeVersion
impl UnicodeVersion
Sourcepub const ALL: [UnicodeVersion; 11]
pub const ALL: [UnicodeVersion; 11]
Every bundled Unicode version, oldest to newest.
Sourcepub const fn latest() -> UnicodeVersion
pub const fn latest() -> UnicodeVersion
Get the latest Unicode version.
Sourcepub const fn table(self) -> &'static [&'static [Interval]]
pub const fn table(self) -> &'static [&'static [Interval]]
A sorted slice of slices where each item is a slice of intervals for every Unicode category. They are sorted alphabetically by their full name.
Sourcepub const fn intervals_for(
self,
category: UnicodeCategory,
) -> &'static [Interval] ⓘ
pub const fn intervals_for( self, category: UnicodeCategory, ) -> &'static [Interval] ⓘ
Get a slice of intervals for the provided Unicode category.
Sourcepub const fn normalized_categories(self) -> [UnicodeCategory; 30]
pub const fn normalized_categories(self) -> [UnicodeCategory; 30]
Unicode categories sorted by the number of intervals inside.
Sourcepub fn query<'a>(self) -> IntervalQuery<'a>
pub fn query<'a>(self) -> IntervalQuery<'a>
A Query builder for specifying the input parameters to intervals() / interval_set methods.